'use strict';

const browshot = require('browshot');

var client = new browshot('my_api_key');

var interval;

// all default parameters, instance_id = 12 (free)
client.screenshotCreate(
	{url: 'http://www.google.com/', instance_id: 12, size: 'page' }, 
	function(screenshot) {
		// If the screenshot is already in cache, it could be finished already. Otherwise, wait longer
		if (screenshot.status == 'error') {
			console.log(`Screenshot #${screenshot.id} failed: ${screenshot.error}`);
		}
		else if (screenshot.status == 'finished') {
			screenshotFinished(screenshot);
		}
		else {
			interval = setInterval(checkScreenshot, 1000 * 10, screenshot.id);
		}
	}
);


function checkScreenshot(id) {
	client.screenshotInfo(id, { }, function(screenshot) {
		if (screenshot.status == 'error') {
			clearInterval(interval);
			
			console.log(`Screenshot #${screenshot.id} failed: ${screenshot.error}`);
		}
		else if (screenshot.status == 'finished') {
			clearInterval(interval);
			
			screenshotFinished(screenshot);
		}
		else {
			console.log(`Waiting for screenshot #${screenshot.id} to finish...`);
		}
	});
}

function screenshotFinished(screenshot) {
	// Get a thumbnail at 1/3 (33%) of the original
	client.screenshotThumbnailFile(screenshot.id, "google-1.png", { zoom: 33 }, function(file) {
		console.log(`Thumbnail saved to ${file}`);
	});
	
	// Get a thumbnail with a height of 100 pixels
	client.screenshotThumbnailFile(screenshot.id, "google-2.png", { height: 100 }, function(file) {
		console.log(`Thumbnail saved to ${file}`);
	});
	
	// Get a thumbnail of 200 by 100 pixels at most
	client.screenshotThumbnailFile(screenshot.id, "google-3.png", { height: 100, width: 200 }, function(file) {
		console.log(`Thumbnail saved to ${file}`);
	});
	
	// Crop the screenshot to 768x768, scale it to a 300x300 thumbnail
	client.screenshotThumbnailFile(screenshot.id, "google-4.png", { right:768, bottom: 768, height: 300, width: 300, ratio: 'fit' }, function(file) {
		console.log(`Thumbnail saved to ${file}`);
	});
}